OC.L10N.register(
    "files_external",
    {
    "Please provide a valid Dropbox app key and secret." : "Prezintă te rog o cheie de Dropbox validă și parola",
    "External storage" : "Stocare externă",
    "Local" : "Local",
    "Location" : "Locație",
    "Amazon S3" : "Amazon S3",
    "Key" : "Cheie",
    "Secret" : "Secret",
    "Access Key" : "Cheie de acces",
    "Secret Key" : "Cheie secretă",
    "Hostname" : "Hostname",
    "Port" : "Portul",
    "Region" : "Regiune",
    "Host" : "Gazdă",
    "Username" : "Nume utilizator",
    "Password" : "Parolă",
    "Share" : "Partajează",
    "URL" : "URL",
    "Public key" : "Cheie publică",
    "Access granted" : "Acces permis",
    "Error configuring Dropbox storage" : "Eroare la configurarea mediului de stocare Dropbox",
    "Grant access" : "Permite accesul",
    "Error configuring Google Drive storage" : "Eroare la configurarea mediului de stocare Google Drive",
    "Personal" : "Personal",
    "Saved" : "Salvat",
    "Name" : "Nume",
    "Storage type" : "Tip stocare",
    "External Storage" : "Stocare externă",
    "Folder name" : "Denumire director",
    "Configuration" : "Configurație",
    "Add storage" : "Adauga stocare",
    "Delete" : "Șterge",
    "Enable User External Storage" : "Permite stocare externă pentru utilizatori",
    "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
